# py-solc


Python wrapper around the Helios Protocol `solc` Solidity compiler.


## Dependency

This library requires the `solc` executable to be present.


## Quickstart

Installation

```sh
pip install py-helios-solc
```


See the ethereum solc docs for more details. This is a clone of that library except for the Helios Protocol version of solc.
https://github.com/ethereum/py-solc